pub struct AptosConfig {
pub network: AptosNetwork,
pub rpc_url: String,
pub indexer_url: Option<String>,
pub checkpoint: CheckpointConfig,
pub transaction: TransactionConfig,
pub seal_contract: SealContractConfig,
}Expand description
Complete configuration for the Aptos adapter.
Fields
network: AptosNetworkNetwork to connect to.
rpc_url: StringRPC URL for the Aptos fullnode.
indexer_url: Option<String>Optional indexer URL for GraphQL queries.
checkpoint: CheckpointConfigCheckpoint verification settings.
transaction: TransactionConfigTransaction submission settings.
seal_contract: SealContractConfigCSVSeal contract deployment details.
Implementations
Sourceimpl AptosConfig
impl AptosConfig
Sourcepub fn new(network: AptosNetwork) -> Self
pub fn new(network: AptosNetwork) -> Self
Create a new config for the given network with default RPC URL.
Sourcepub fn with_rpc(network: AptosNetwork, rpc_url: impl Into<String>) -> Self
pub fn with_rpc(network: AptosNetwork, rpc_url: impl Into<String>) -> Self
Create a config with a custom RPC URL.
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Validate the configuration is correct for the target network.
Sourcepub fn f_plus_one(&self) -> u64
pub fn f_plus_one(&self) -> u64
Returns the expected 2f+1 threshold for validator signatures. In production, this should match the actual validator set.